@@ -119,6 +119,7 @@
 /usr/share/doc/JFdocs/LDAP-Implementation-HOWTO.txt.gz
 /usr/share/doc/JFdocs/LDP-Author-Guide.txt.gz
 /usr/share/doc/JFdocs/LF1000.txt.gz
+/usr/share/doc/JFdocs/LFS-BOOK.txt.gz
 /usr/share/doc/JFdocs/LIDS-FAQ.txt.gz
 /usr/share/doc/JFdocs/LILO-FAQ.txt.gz
 /usr/share/doc/JFdocs/LILO-README.txt.gz
@@ -202,6 +203,7 @@
 /usr/share/doc/JFdocs/Qmail+MH.txt.gz
 /usr/share/doc/JFdocs/Quota.txt.gz
 /usr/share/doc/JFdocs/RCS.txt.gz
+/usr/share/doc/JFdocs/RFC-HOWTO-find-oops-location.txt.gz
 /usr/share/doc/JFdocs/RPM+Slackware.txt.gz
 /usr/share/doc/JFdocs/RPM-HOWTO.txt.gz
 /usr/share/doc/JFdocs/RTLinux-HOWTO.txt.gz
@@ -246,7 +248,6 @@
 /usr/share/doc/JFdocs/StarOffice.txt.gz
 /usr/share/doc/JFdocs/Text-Terminal-HOWTO.txt.gz
 /usr/share/doc/JFdocs/Text-To-Speech-mini-HOWTO.txt.gz
-/usr/share/doc/JFdocs/The-Linux-Kernel.txt.gz
 /usr/share/doc/JFdocs/The-Software-RAID-HOWTO.txt.gz
 /usr/share/doc/JFdocs/TimePrecision-HOWTO.txt.gz
 /usr/share/doc/JFdocs/Tips-HOWTO.txt.gz
@@ -269,6 +270,7 @@
 /usr/share/doc/JFdocs/Visual-Bell.txt.gz
 /usr/share/doc/JFdocs/WWW-mSQL-HOWTO.txt.gz
 /usr/share/doc/JFdocs/Wearable-HOWTO.txt.gz
+/usr/share/doc/JFdocs/WhyReiser4IsNotIn.txt.gz
 /usr/share/doc/JFdocs/Windows-LAN-Server-HOWTO.txt.gz
 /usr/share/doc/JFdocs/Windows-Modem-Sharing.txt.gz
 /usr/share/doc/JFdocs/Wine-FAQ.txt.gz
@@ -331,8 +333,9 @@
 /usr/share/doc/JFdocs/archive/pLaTeX2e.txt.gz
 /usr/share/doc/JFdocs/archive/tutri1_3.txt.gz
 /usr/share/doc/JFdocs/blinux.txt.gz
-/usr/share/doc/JFdocs/contrib/LILO-doc/rpm.txt
-/usr/share/doc/JFdocs/contrib/LILO-doc/userconf.txt
+/usr/share/doc/JFdocs/build/PlamoBuild.JFdocs20080828.gz
+/usr/share/doc/JFdocs/contrib/LILO-doc/rpm.txt.gz
+/usr/share/doc/JFdocs/contrib/LILO-doc/userconf.txt.gz
 /usr/share/doc/JFdocs/cqcam.txt.gz
 /usr/share/doc/JFdocs/debiantips.txt.gz
 /usr/share/doc/JFdocs/docbook-intro.txt.gz
@@ -373,7 +376,8 @@
 /usr/share/doc/JFdocs/sgmlmemo.txt.gz
 /usr/share/doc/JFdocs/sgmlnote.txt.gz
 /usr/share/doc/JFdocs/tkxauth.txt.gz
+/usr/share/doc/JFdocs/tpp.txt.gz
 /usr/share/doc/JFdocs/traffic-control.txt.gz
 /usr/share/doc/JFdocs/vi-user-usage.txt.gz
-## indexed: Sun, 18 Apr 2004 11:07:41
+## indexed: Tue, 30 Sep 2008 13:32:03 +0900
 
